# Changelog (Under construction)

All changes to **Eventide** will be documented in this file.

This project follows [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.0.1] - 2025-06-01

### Breaking changes

- Breaking change ([#1](https://github.com/lvieirajr/eventide/pull/))

### Features and Improvements

- New feature ([#1](https://github.com/lvieirajr/eventide/pull/))

### Bug fixes

- Bug fix ([#1](https://github.com/lvieirajr/eventide/pull/))
